##  Prerequisites
Do the following:
  * Get access to your repository and ensure that you can modify its Continuous Integration and Continuous Deployment (CI/CD) pipeline.
  * In SAP LeanIX, get an API token by creating a technical user with admin permissions. For instructions, see [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD "To get an API token, create a technical user. Manage technical users collaboratively with other administrators.").


This guide assumes you have a basic understanding of:
  * CI/CD concepts and practices
  * [YAML![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fyaml.org%2F "https://yaml.org/")
  * [Self-Built Software Discovery API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Feu.leanix.net%2Fservices%2Ftechnology-discovery%2Fv1%2Fopenapi%2Fswagger-ui%2Findex.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://eu.leanix.net/services/technology-discovery/v1/openapi/swagger-ui/index.html")
  * [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of SAP LeanIX Technology Risk and Compliance, with links to detailed guides for managing obsolescence risk, optimizing technology usage, and enforcing tech standards across your IT landscape.") product, including its [technology standards management capabilities](https://help.sap.com/docs/leanix/ea/technology-standards-management-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX Technology Risk and Compliance facilitates inventorizing the technology landscape, provides comprehensive visibility, and helps you derive data-driven decisions to standardize the technology landscape.")
